pqp.estimation package
======================

Submodules
----------

pqp.estimation.estimator module
-------------------------------

.. automodule:: pqp.estimation.estimator
   :members:
   :undoc-members:
   :show-inheritance:

pqp.estimation.multinomial\_estimator module
--------------------------------------------

.. automodule:: pqp.estimation.multinomial_estimator
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pqp.estimation
   :members:
   :undoc-members:
   :show-inheritance:
